
From: Bjorn Helgaas <bjorn.helgaas@hp.com>

This patch
	- adds copyright and license info
	- changes sense of mmap config option (setting option enables mmap
	  instead of disabling it, to avoid the double negative)
	- removes an #ifdef CONFIG_IA64 now that acpi_register_gsi()
	  is generic.

Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/char/Kconfig |   16 ++++++++++------
 25-akpm/drivers/char/hpet.c  |   20 +++++++++++---------
 2 files changed, 21 insertions(+), 15 deletions(-)

diff -puN drivers/char/hpet.c~hpet-copyrights-cleanup drivers/char/hpet.c
--- 25/drivers/char/hpet.c~hpet-copyrights-cleanup	2004-07-31 17:03:05.407842272 -0700
+++ 25-akpm/drivers/char/hpet.c	2004-07-31 17:03:05.415841056 -0700
@@ -1,8 +1,14 @@
 /*
  * Intel & MS High Precision Event Timer Implementation.
- * Contributors:
+ *
+ * Copyright (C) 2003 Intel Corporation
  *	Venki Pallipadi
- * 	Bob Picco
+ * (c) Copyright 2004 Hewlett-Packard Development Company, L.P.
+ *	Bob Picco <robert.picco@hp.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
  */
 
 #include <linux/config.h>
@@ -250,9 +256,7 @@ static unsigned int hpet_poll(struct fil
 
 static int hpet_mmap(struct file *file, struct vm_area_struct *vma)
 {
-#ifdef	CONFIG_HPET_NOMMAP
-	return -ENOSYS;
-#else
+#ifdef	CONFIG_HPET_MMAP
 	struct hpet_dev *devp;
 	unsigned long addr;
 
@@ -276,6 +280,8 @@ static int hpet_mmap(struct file *file, 
 	}
 
 	return 0;
+#else
+	return -ENOSYS;
 #endif
 }
 
@@ -901,14 +907,10 @@ static acpi_status __init hpet_resources
 			hdp->hd_nirqs = irqp->number_of_interrupts;
 
 			for (i = 0; i < hdp->hd_nirqs; i++)
-#ifdef	CONFIG_IA64
 				hdp->hd_irq[i] =
 				    acpi_register_gsi(irqp->interrupts[i],
 						      irqp->edge_level,
 						      irqp->active_high_low);
-#else
-				hdp->hd_irq[i] = irqp->interrupts[i];
-#endif
 		}
 	}
 
diff -puN drivers/char/Kconfig~hpet-copyrights-cleanup drivers/char/Kconfig
--- 25/drivers/char/Kconfig~hpet-copyrights-cleanup	2004-07-31 17:03:05.408842120 -0700
+++ 25-akpm/drivers/char/Kconfig	2004-07-31 17:03:05.414841208 -0700
@@ -976,14 +976,18 @@ config HPET_RTC_IRQ
 	  is assumed the platform called hpet_alloc with the RTC IRQ values for
 	  the HPET timers.
 
-config HPET_NOMMAP
-	bool "HPET - Control mmap capability."
-	default n
+config HPET_MMAP
+	bool "Allow mmap of HPET"
+	default y
 	depends on HPET
 	help
-	  If you say Y here, then the mmap interface for the HPET driver returns ENOSYS.
-	  Some hardware implementations might not want all the memory in the page the
-	  HPET control registers reside to be exposed.
+	  If you say Y here, user applications will be able to mmap
+	  the HPET registers.
+
+	  In some hardware implementations, the page containing HPET
+	  registers may also contain other things that shouldn't be
+	  exposed to the user.  If this applies to your hardware,
+	  say N here.
 
 config MAX_RAW_DEVS
 	int "Maximum number of RAW devices to support (1-8192)"
_
